==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/backup_plan/BackupPlanRuleLifecycle.java <==
package com.hashicorp.cdktf.providers.aws.backup_plan;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:51.811Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.backupPlan.BackupPlanRuleLifecycle")
@software.amazon.jsii.Jsii.Proxy(BackupPlanRuleLifecycle.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BackupPlanRuleLifecycle extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getColdStorageAfter() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#delete_after BackupPlan#delete_after}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getDeleteAfter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BackupPlanRuleLifecycle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BackupPlanRuleLifecycle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BackupPlanRuleLifecycle> {
        java.lang.Number coldStorageAfter;
        java.lang.Number deleteAfter;

        /**
         * Sets the value of {@link BackupPlanRuleLifecycle#getColdStorageAfter}
         * @param coldStorageAfter Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder coldStorageAfter(java.lang.Number coldStorageAfter) {
            this.coldStorageAfter = coldStorageAfter;
            return this;
        }

        /**
         * Sets the value of {@link BackupPlanRuleLifecycle#getDeleteAfter}
         * @param deleteAfter Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#delete_after BackupPlan#delete_after}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteAfter(java.lang.Number deleteAfter) {
            this.deleteAfter = deleteAfter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BackupPlanRuleLifecycle}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BackupPlanRuleLifecycle build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BackupPlanRuleLifecycle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BackupPlanRuleLifecycle {
        private final java.lang.Number coldStorageAfter;
        private final java.lang.Number deleteAfter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.coldStorageAfter = software.amazon.jsii.Kernel.get(this, "coldStorageAfter", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.deleteAfter = software.amazon.jsii.Kernel.get(this, "deleteAfter", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.coldStorageAfter = builder.coldStorageAfter;
            this.deleteAfter = builder.deleteAfter;
        }

        @Override
        public final java.lang.Number getColdStorageAfter() {
            return this.coldStorageAfter;
        }

        @Override
        public final java.lang.Number getDeleteAfter() {
            return this.deleteAfter;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getColdStorageAfter() != null) {
                data.set("coldStorageAfter", om.valueToTree(this.getColdStorageAfter()));
            }
            if (this.getDeleteAfter() != null) {
                data.set("deleteAfter", om.valueToTree(this.getDeleteAfter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.backupPlan.BackupPlanRuleLifecycle"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BackupPlanRuleLifecycle.Jsii$Proxy that = (BackupPlanRuleLifecycle.Jsii$Proxy) o;

            if (this.coldStorageAfter != null ? !this.coldStorageAfter.equals(that.coldStorageAfter) : that.coldStorageAfter != null) return false;
            return this.deleteAfter != null ? this.deleteAfter.equals(that.deleteAfter) : that.deleteAfter == null;
        }

        @Override
        public final int hashCode() {
            int result = this.coldStorageAfter != null ? this.coldStorageAfter.hashCode() : 0;
            result = 31 * result + (this.deleteAfter != null ? this.deleteAfter.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/backup_plan/BackupPlanRuleLifecycle.java <==
package com.hashicorp.cdktf.providers.aws.backup_plan;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.585Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.backupPlan.BackupPlanRuleLifecycle")
@software.amazon.jsii.Jsii.Proxy(BackupPlanRuleLifecycle.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BackupPlanRuleLifecycle extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getColdStorageAfter() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/backup_plan#delete_after BackupPlan#delete_after}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getDeleteAfter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BackupPlanRuleLifecycle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BackupPlanRuleLifecycle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BackupPlanRuleLifecycle> {
        java.lang.Number coldStorageAfter;
        java.lang.Number deleteAfter;

        /**
         * Sets the value of {@link BackupPlanRuleLifecycle#getColdStorageAfter}
         * @param coldStorageAfter Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder coldStorageAfter(java.lang.Number coldStorageAfter) {
            this.coldStorageAfter = coldStorageAfter;
            return this;
        }

        /**
         * Sets the value of {@link BackupPlanRuleLifecycle#getDeleteAfter}
         * @param deleteAfter Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/backup_plan#delete_after BackupPlan#delete_after}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteAfter(java.lang.Number deleteAfter) {
            this.deleteAfter = deleteAfter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BackupPlanRuleLifecycle}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BackupPlanRuleLifecycle build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BackupPlanRuleLifecycle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BackupPlanRuleLifecycle {
        private final java.lang.Number coldStorageAfter;
        private final java.lang.Number deleteAfter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.coldStorageAfter = software.amazon.jsii.Kernel.get(this, "coldStorageAfter", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.deleteAfter = software.amazon.jsii.Kernel.get(this, "deleteAfter", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.coldStorageAfter = builder.coldStorageAfter;
            this.deleteAfter = builder.deleteAfter;
        }

        @Override
        public final java.lang.Number getColdStorageAfter() {
            return this.coldStorageAfter;
        }

        @Override
        public final java.lang.Number getDeleteAfter() {
            return this.deleteAfter;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getColdStorageAfter() != null) {
                data.set("coldStorageAfter", om.valueToTree(this.getColdStorageAfter()));
            }
            if (this.getDeleteAfter() != null) {
                data.set("deleteAfter", om.valueToTree(this.getDeleteAfter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.backupPlan.BackupPlanRuleLifecycle"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BackupPlanRuleLifecycle.Jsii$Proxy that = (BackupPlanRuleLifecycle.Jsii$Proxy) o;

            if (this.coldStorageAfter != null ? !this.coldStorageAfter.equals(that.coldStorageAfter) : that.coldStorageAfter != null) return false;
            return this.deleteAfter != null ? this.deleteAfter.equals(that.deleteAfter) : that.deleteAfter == null;
        }

        @Override
        public final int hashCode() {
            int result = this.coldStorageAfter != null ? this.coldStorageAfter.hashCode() : 0;
            result = 31 * result + (this.deleteAfter != null ? this.deleteAfter.hashCode() : 0);
            return result;
        }
    }
}
